.. _signal_analysis.mutual_info:

Mutual Information
==================

.. automodule:: eyetrace.signal_analysis.mutual_info
   :members:
   :undoc-members:
   :show-inheritance:

Mutual information measures the amount of information shared between two
signals, capturing both linear and non‑linear dependencies. It is useful for
assessing synchronization (e.g., between left and right eye movements).